==> segatex-8.500.tar.gz: segatex-8.500/src/breakte.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2013 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qlayout.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qradiobutton.h>
#include <q3textedit.h>
#include <q3process.h>
#include <qmessagebox.h>
//Added by qt3to4:
#include <Q3TextStream>
#include <Q3HBoxLayout>
#include <Q3VBoxLayout>
#include <fstream>

#include "breakte.h"

#include <iostream>
using namespace std;

//default constructor
BreakTe::BreakTe(QWidget *parent, const char *name): QDialog(parent, name)
{
		setCaption(tr("break .te files"));
		textEdit1 = new Q3TextEdit(this);
		textEdit1->setPaletteBackgroundColor(QColor(174,187,255));
		closeButton = new QPushButton(tr("&Close"), this);
		breakteButton = new QPushButton(tr("break .te files"), this);
		breakteButton->setPaletteBackgroundColor(QColor(255, 155, 155));
		breakteButton->setDefault(true);

		connect(breakteButton, SIGNAL(clicked()), this, SLOT(breakte_clicked()));
		connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));

		firstLayout = new Q3VBoxLayout;
		leftLayout = new Q3HBoxLayout;

		rightLayout = new Q3VBoxLayout;
		rightLayout->addWidget(breakteButton);
		rightLayout->addWidget(closeButton);

		firstLayout->addLayout(leftLayout);
		firstLayout->addWidget(textEdit1);

		mainLayout = new Q3HBoxLayout(this);
		mainLayout->setMargin(11);
		mainLayout->setSpacing(6);
		mainLayout->addLayout(firstLayout);
		mainLayout->addLayout(rightLayout);

		resize(1000,600);
}
void BreakTe::breakte_clicked()
{
		breakte_base_process();
}
////////////////////////////////////////////
void BreakTe::readFromStdout()
{
        QByteArray data = process->readStdout();
        QString text = textEdit1->text() + QString(data);
        textEdit1->setText(text);
}
void BreakTe::processExited()
{
	if(process->normalExit()){

	} else {
		textEdit1->append(tr("breakte process had an error !"));
		textEdit1->append(tr("\n"));
	}
	delete process;
	process = 0;
	this->setEnabled(true);
}
void BreakTe::breakte_base_process()
{
	this->setEnabled(false);
	process = new Q3Process(this);
	process->addArgument("/usr/share/segatex/raw_te_files/breakte.sh");

	outputfile_str = "breakte";
	path = "/usr/share/segatex";
	forward_slash = "/";
	outputfile_str = path + forward_slash + outputfile_str;
	connect(process, SIGNAL(readyReadStdout()),this,SLOT(readFromStdout()));
	connect(process, SIGNAL(processExited()),this,SLOT(processExited()));
	process->start();

	readFromOutputFile();
}

//this slot should be called from above slot
void BreakTe::readFromOutputFile()
{
	/////////////////////////////////////////////////////////////
	path = "/usr/share/segatex";
	/////////////////////////////////////////////////////////////
	forward_slash = "/";
	dir.setPath(path);
	dir_name = dir.absPath();
	/////////////////////////////////////////////////////////////
	dir.setFilter( QDir::Files );
        dir.setSorting( QDir::Name );
	//files = dir.entryList(outputfile_str_common);
	files = dir.entryList("breakte");
	/////////////////////////////////////////////////////////////
	it_d = files.begin();
	textEdit1->clear();
		while(it_d != files.end()){
			name = *it_d;
			file_interface_name = dir_name + forward_slash + name;
			QFile file( file_interface_name );
			if ( file.open( QIODevice::ReadOnly ) ) {
				Q3TextStream stream( &file );
				////////////////////////////////////////////
				while ( !stream.atEnd() ) {
					line_analized = stream.readLine(); // line of text excluding '\n'
					textEdit1->append(line_analized);
				}
				file.close();
				++it_d;
			}else{
				//do nothing
			}
		}
		textEdit1->setCursorPosition(0,0);
}

==> segatex-8.600.tar.gz: segatex-8.600/src/breakte.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <QLayout>
#include <QLineEdit>
#include <QPushButton>
#include <QRadioButton>
#include <QTextEdit>
#include <QMessageBox>
#include <Q3TextStream>
#include <fstream>

#include "breakte.h"

#include <iostream>
using namespace std;

// constructor
BreakTe::BreakTe(QWidget *parent, const char *name): QDialog(parent, name)
{
		setCaption(tr("break .te files"));
		textEdit1 = new QTextEdit(this);
		textEdit1->setPaletteBackgroundColor(QColor(174,187,255));
		closeButton = new QPushButton(tr("&Close"), this);
		breakteButton = new QPushButton(tr("break .te files"), this);
		breakteButton->setPaletteBackgroundColor(QColor(255, 155, 155));
		breakteButton->setDefault(true);

		connect(breakteButton, SIGNAL(clicked()), this, SLOT(breakte_clicked()));
		connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));

		firstLayout = new QVBoxLayout;
		leftLayout = new QHBoxLayout;

		rightLayout = new QVBoxLayout;
		rightLayout->addWidget(breakteButton);
		rightLayout->addWidget(closeButton);

		firstLayout->addLayout(leftLayout);
		firstLayout->addWidget(textEdit1);

		mainLayout = new QHBoxLayout(this);
		mainLayout->setMargin(11);
		mainLayout->setSpacing(6);
		mainLayout->addLayout(firstLayout);
		mainLayout->addLayout(rightLayout);

		resize(1000,600);
}
void BreakTe::processExited(int exitCode, QProcess::ExitStatus exitStatus)
{
	if ( exitStatus == QProcess::CrashExit )
	{
		//QMessageBox::warning( this, tr("Error"), tr("Crashed") );
		textEdit1->append(tr("Error, Crashed !"));
		textEdit1->append(tr("\n"));
	}
	else if ( exitCode != 0 )
	{
		//QMessageBox::warning( this, tr("Error"), tr("Failed") );
		textEdit1->append(tr("Error, Failed !"));
		textEdit1->append(tr("\n"));
	}
	else
	{
		textEdit1->append(tr("breakte  process ended !"));
		textEdit1->append(tr("\n"));
        }
	delete process;
	process = 0;
	this->setEnabled(true);
}
void BreakTe::breakte_clicked()
{
		breakte_base_process();
}
////////////////////////////////////////////
void BreakTe::readFromStdout()
{
        QByteArray data = process->readAllStandardOutput();
        QString text = textEdit1->text() + QString(data);
        textEdit1->setText(text);
}
void BreakTe::updateOutputTextEdit()
{
	QByteArray data = process->readAllStandardError();
	QString text = textEdit1->text() + QString(data);
	textEdit1->setText(text);
}
void BreakTe::breakte_base_process()
{
	this->setEnabled(false);
	process = new QProcess(this);

	connect(process, SIGNAL(readyReadStandardOutput()),this,SLOT(readFromStdout()));
	connect(process, SIGNAL(readyReadStandardError()),this,SLOT(updateOutputTextEdit()));
	connect(process, SIGNAL(finished(int, QProcess::ExitStatus)),this,SLOT(processExited(int, QProcess::ExitStatus)));
	process->start("/usr/share/segatex/raw_te_files/breakte.sh");
}
